@@ -100,7 +100,7 @@
 //! # }
 //! ```
 //!
-//! ## Choosing `ChaChaBox` vs `SalasaBox`
+//! ## Choosing `ChaChaBox` vs `SalsaBox`
 //!
 //! Currently, `crypto_box::Box` is default to use `xsalsa20poly1305` which doesn't support non-empty associated data
 //! field. To specify customized AD, you can use `crypto_box::ChaChaBox` instead.
@@ -186,9 +186,10 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/media/6ee8e381/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/6ee8e381/logo.svg",
-    html_root_url = "https://docs.rs/crypto_box/0.7.1"
+    html_root_url = "https://docs.rs/crypto_box/0.7.2"
 )]
 #![warn(missing_docs, rust_2018_idioms)]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 
 pub use rand_core;
 pub use xsalsa20poly1305::{aead, generate_nonce};
